templates = [
    "Do you have a {}? Because whenever I look at you, everyone else disappears.",
    "Are you a {}? Because every time I think of you, I smile.",
    "Do you have a map? I keep getting lost in your {}.",
    "If beauty were time, you'd be an {}.",
    "I'm not a photographer, but I can picture us together in a {}.",
    "Can I follow you home? Cause my parents always told me to follow my {}.",
    "Is your name Google? Because you have everything I've been searching for in the {}.",
    "Are you made of copper and tellurium? Because you're {}.",
    "Do you like Star Wars? Because Yoda only one for me in the {}.",
    "If you were a {} on a McDonald's menu, you'd be a McGorgeous.",
    "Do you have a Band-Aid? Because I just scraped my knee falling for {}.",
    "Is it hot in here or is it just the {} we have together?",
    "If you were a vegetable, you'd be a {}.",
    "I must be a {} because I am attracted to your magnetic field.",
    "Is there an airport nearby or is that just my heart taking {}?",
    "You must be a magician because whenever I look at you, everyone else {}.",
    "If I could rearrange the alphabet, I'd put {} and {} together.",
    "Are you a {}? Because you're so fine you blow my mind.",
    "Do you have a pencil? Cause I want to erase your past and write our {}.",
    "Do you know what my shirt is made of? It's made of boyfriend {}.",
    "Are you a {}? Because you just brightened my day with a single smile.",
    "I'm not a genie, but I can make your {} come true.",
    "If you were a {}, you'd be a sweet one.",
    "Was that an earthquake, or did you just rock my {}?",
    "Do you have a name, or can I call you {}?",
    "If we were at home, cuddling on a rainy Sunday morning, what would we have for {}? Pancakes, bacon, or {}?",
    "Excuse me, but I think you dropped something: MY {}.",
    "If you were a fruit, you'd be a {}apple.",
    "Are you a {}? Because every time I look at you, I feel like I'm on cloud nine.",
    "Do you play soccer? Because you're a {} in the field.",
    "If you were words on a page, you'd be the {} print.",
    "Did we just share an {}? Because I feel like I've known you forever.",
    "I'm writing a term paper on the finer things in life. Can I interview you over {}?",
    "I'd never play hide and seek with you because someone like you is impossible to {}.",
    "Can I take a picture of you, so I can show Santa what I want for {}?",
    "Do you have a sunburn, or are you always this {}?",
    "If you were a {} in the sea, I'd swim all the oceans to find you.",
    "You must be the square root of -1 because you can't be {}.",
    "Is it okay if I follow you home? Because my parents always told me to follow my {}.",
    "If you were a {}, you'd be an extraordinary one."
]